/*******************************************************************************
* File Name: Iadc.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_Iadc_H) /* Pins Iadc_H */
#define CY_PINS_Iadc_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "Iadc_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 Iadc__PORT == 15 && ((Iadc__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    Iadc_Write(uint8 value);
void    Iadc_SetDriveMode(uint8 mode);
uint8   Iadc_ReadDataReg(void);
uint8   Iadc_Read(void);
void    Iadc_SetInterruptMode(uint16 position, uint16 mode);
uint8   Iadc_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the Iadc_SetDriveMode() function.
     *  @{
     */
        #define Iadc_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define Iadc_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define Iadc_DM_RES_UP          PIN_DM_RES_UP
        #define Iadc_DM_RES_DWN         PIN_DM_RES_DWN
        #define Iadc_DM_OD_LO           PIN_DM_OD_LO
        #define Iadc_DM_OD_HI           PIN_DM_OD_HI
        #define Iadc_DM_STRONG          PIN_DM_STRONG
        #define Iadc_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define Iadc_MASK               Iadc__MASK
#define Iadc_SHIFT              Iadc__SHIFT
#define Iadc_WIDTH              1u

/* Interrupt constants */
#if defined(Iadc__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in Iadc_SetInterruptMode() function.
     *  @{
     */
        #define Iadc_INTR_NONE      (uint16)(0x0000u)
        #define Iadc_INTR_RISING    (uint16)(0x0001u)
        #define Iadc_INTR_FALLING   (uint16)(0x0002u)
        #define Iadc_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define Iadc_INTR_MASK      (0x01u) 
#endif /* (Iadc__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define Iadc_PS                     (* (reg8 *) Iadc__PS)
/* Data Register */
#define Iadc_DR                     (* (reg8 *) Iadc__DR)
/* Port Number */
#define Iadc_PRT_NUM                (* (reg8 *) Iadc__PRT) 
/* Connect to Analog Globals */                                                  
#define Iadc_AG                     (* (reg8 *) Iadc__AG)                       
/* Analog MUX bux enable */
#define Iadc_AMUX                   (* (reg8 *) Iadc__AMUX) 
/* Bidirectional Enable */                                                        
#define Iadc_BIE                    (* (reg8 *) Iadc__BIE)
/* Bit-mask for Aliased Register Access */
#define Iadc_BIT_MASK               (* (reg8 *) Iadc__BIT_MASK)
/* Bypass Enable */
#define Iadc_BYP                    (* (reg8 *) Iadc__BYP)
/* Port wide control signals */                                                   
#define Iadc_CTL                    (* (reg8 *) Iadc__CTL)
/* Drive Modes */
#define Iadc_DM0                    (* (reg8 *) Iadc__DM0) 
#define Iadc_DM1                    (* (reg8 *) Iadc__DM1)
#define Iadc_DM2                    (* (reg8 *) Iadc__DM2) 
/* Input Buffer Disable Override */
#define Iadc_INP_DIS                (* (reg8 *) Iadc__INP_DIS)
/* LCD Common or Segment Drive */
#define Iadc_LCD_COM_SEG            (* (reg8 *) Iadc__LCD_COM_SEG)
/* Enable Segment LCD */
#define Iadc_LCD_EN                 (* (reg8 *) Iadc__LCD_EN)
/* Slew Rate Control */
#define Iadc_SLW                    (* (reg8 *) Iadc__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define Iadc_PRTDSI__CAPS_SEL       (* (reg8 *) Iadc__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define Iadc_PRTDSI__DBL_SYNC_IN    (* (reg8 *) Iadc__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define Iadc_PRTDSI__OE_SEL0        (* (reg8 *) Iadc__PRTDSI__OE_SEL0) 
#define Iadc_PRTDSI__OE_SEL1        (* (reg8 *) Iadc__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define Iadc_PRTDSI__OUT_SEL0       (* (reg8 *) Iadc__PRTDSI__OUT_SEL0) 
#define Iadc_PRTDSI__OUT_SEL1       (* (reg8 *) Iadc__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define Iadc_PRTDSI__SYNC_OUT       (* (reg8 *) Iadc__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(Iadc__SIO_CFG)
    #define Iadc_SIO_HYST_EN        (* (reg8 *) Iadc__SIO_HYST_EN)
    #define Iadc_SIO_REG_HIFREQ     (* (reg8 *) Iadc__SIO_REG_HIFREQ)
    #define Iadc_SIO_CFG            (* (reg8 *) Iadc__SIO_CFG)
    #define Iadc_SIO_DIFF           (* (reg8 *) Iadc__SIO_DIFF)
#endif /* (Iadc__SIO_CFG) */

/* Interrupt Registers */
#if defined(Iadc__INTSTAT)
    #define Iadc_INTSTAT            (* (reg8 *) Iadc__INTSTAT)
    #define Iadc_SNAP               (* (reg8 *) Iadc__SNAP)
    
	#define Iadc_0_INTTYPE_REG 		(* (reg8 *) Iadc__0__INTTYPE)
#endif /* (Iadc__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_Iadc_H */


/* [] END OF FILE */
