/*******************************************************************************
* File Name: TFF.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_TFF_H) /* Pins TFF_H */
#define CY_PINS_TFF_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "TFF_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 TFF__PORT == 15 && ((TFF__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    TFF_Write(uint8 value);
void    TFF_SetDriveMode(uint8 mode);
uint8   TFF_ReadDataReg(void);
uint8   TFF_Read(void);
void    TFF_SetInterruptMode(uint16 position, uint16 mode);
uint8   TFF_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the TFF_SetDriveMode() function.
     *  @{
     */
        #define TFF_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define TFF_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define TFF_DM_RES_UP          PIN_DM_RES_UP
        #define TFF_DM_RES_DWN         PIN_DM_RES_DWN
        #define TFF_DM_OD_LO           PIN_DM_OD_LO
        #define TFF_DM_OD_HI           PIN_DM_OD_HI
        #define TFF_DM_STRONG          PIN_DM_STRONG
        #define TFF_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define TFF_MASK               TFF__MASK
#define TFF_SHIFT              TFF__SHIFT
#define TFF_WIDTH              1u

/* Interrupt constants */
#if defined(TFF__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in TFF_SetInterruptMode() function.
     *  @{
     */
        #define TFF_INTR_NONE      (uint16)(0x0000u)
        #define TFF_INTR_RISING    (uint16)(0x0001u)
        #define TFF_INTR_FALLING   (uint16)(0x0002u)
        #define TFF_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define TFF_INTR_MASK      (0x01u) 
#endif /* (TFF__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define TFF_PS                     (* (reg8 *) TFF__PS)
/* Data Register */
#define TFF_DR                     (* (reg8 *) TFF__DR)
/* Port Number */
#define TFF_PRT_NUM                (* (reg8 *) TFF__PRT) 
/* Connect to Analog Globals */                                                  
#define TFF_AG                     (* (reg8 *) TFF__AG)                       
/* Analog MUX bux enable */
#define TFF_AMUX                   (* (reg8 *) TFF__AMUX) 
/* Bidirectional Enable */                                                        
#define TFF_BIE                    (* (reg8 *) TFF__BIE)
/* Bit-mask for Aliased Register Access */
#define TFF_BIT_MASK               (* (reg8 *) TFF__BIT_MASK)
/* Bypass Enable */
#define TFF_BYP                    (* (reg8 *) TFF__BYP)
/* Port wide control signals */                                                   
#define TFF_CTL                    (* (reg8 *) TFF__CTL)
/* Drive Modes */
#define TFF_DM0                    (* (reg8 *) TFF__DM0) 
#define TFF_DM1                    (* (reg8 *) TFF__DM1)
#define TFF_DM2                    (* (reg8 *) TFF__DM2) 
/* Input Buffer Disable Override */
#define TFF_INP_DIS                (* (reg8 *) TFF__INP_DIS)
/* LCD Common or Segment Drive */
#define TFF_LCD_COM_SEG            (* (reg8 *) TFF__LCD_COM_SEG)
/* Enable Segment LCD */
#define TFF_LCD_EN                 (* (reg8 *) TFF__LCD_EN)
/* Slew Rate Control */
#define TFF_SLW                    (* (reg8 *) TFF__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define TFF_PRTDSI__CAPS_SEL       (* (reg8 *) TFF__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define TFF_PRTDSI__DBL_SYNC_IN    (* (reg8 *) TFF__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define TFF_PRTDSI__OE_SEL0        (* (reg8 *) TFF__PRTDSI__OE_SEL0) 
#define TFF_PRTDSI__OE_SEL1        (* (reg8 *) TFF__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define TFF_PRTDSI__OUT_SEL0       (* (reg8 *) TFF__PRTDSI__OUT_SEL0) 
#define TFF_PRTDSI__OUT_SEL1       (* (reg8 *) TFF__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define TFF_PRTDSI__SYNC_OUT       (* (reg8 *) TFF__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(TFF__SIO_CFG)
    #define TFF_SIO_HYST_EN        (* (reg8 *) TFF__SIO_HYST_EN)
    #define TFF_SIO_REG_HIFREQ     (* (reg8 *) TFF__SIO_REG_HIFREQ)
    #define TFF_SIO_CFG            (* (reg8 *) TFF__SIO_CFG)
    #define TFF_SIO_DIFF           (* (reg8 *) TFF__SIO_DIFF)
#endif /* (TFF__SIO_CFG) */

/* Interrupt Registers */
#if defined(TFF__INTSTAT)
    #define TFF_INTSTAT            (* (reg8 *) TFF__INTSTAT)
    #define TFF_SNAP               (* (reg8 *) TFF__SNAP)
    
	#define TFF_0_INTTYPE_REG 		(* (reg8 *) TFF__0__INTTYPE)
#endif /* (TFF__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_TFF_H */


/* [] END OF FILE */
